package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````V!<``#0```"`D0````(`!30`(``)
M`"@`&P`:``$``'!PB@``<(H``'"*```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$```````````````````!\B@``?(H```4```````$`
M`0```'R*``!\B@$`?(H!`,0%``#8%0``!@```````0`"````A(H``(2*`0"$
MB@$`$`$``!`!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D?(H`
M`'R*`0!\B@$`A`4``(0%```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!0````#````1TY5`$#2M5'),(BY1]RMN"E[8C7'R_<A!````!`````!
M````1TY5```````#`````@`````````1````3`````@````(`````9`0!"5`
M!(`H@``%H(90A(`!```+*`2,.*`218H```A,````30```%````!4````50``
M`%T```!>````7P```&$```!B````9````&4```!F````9P```&H`````````
M``````&O-.ANQ=\?SMY'+6M_FGPNQ9NV=E0\E"#_Y`[59-1\V7%8'.)'Q@%"
M^M>'K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#UF>OS&9"1=7LB0=PTPT4
MXI[:S>.>,V+;[16,)<P-.I<+?ZF<F[[:5QO@IP(*:QJ>4*/@^TD`````````
M`````````````````"P2`````````P`+````````D`$```````,`%@!``@``
M```````````2````U`(`````````````$@```*@"`````````````"(```#M
M`@`````````````1````E`,`````````````$@````$``````````````"``
M``"F`0`````````````2````AP(`````````````$@```,4"````````````
M`!(```#X```````````````2````"0,`````````````$0```%L"````````
M`````!(```!<`0`````````````2````8@(`````````````$@```$<"````
M`````````!(```!T```````````````2````\P``````````````$@```&H"
M`````````````!(````D`@`````````````2````Z@$`````````````$@``
M`/<"`````````````!(```!C`@`````````````2````^P$`````````````
M$@````@"`````````````!(```#1```````````````1````3@$`````````
M````$@```+,``````````````!$````<`0`````````````2````C@(`````
M````````$@```(`"`````````````!$```"*`0`````````````2````L@$`
M````````````$@```'<!`````````````!(```!X`@`````````````2````
MJP$`````````````$@```(,!`````````````!(```#;`@`````````````2
M````*@$`````````````$@```!T``````````````"`````=`@``````````
M```2````U`$`````````````$@```#("`````````````!(```!4````````
M```````2````EP(`````````````$@```(,``````````````!(```"5`0``
M```````````2````MP(`````````````$@```(\``````````````!(```!#
M`0`````````````2`````@(`````````````$@```#D"`````````````!(`
M```)`0`````````````2````1@``````````````$@```/T`````````````
M`!(```!L`0`````````````2````30(`````````````$@```,``````````
M`````!(````6`@`````````````2````S0(`````````````$@```-P`````
M`````````!(````K`@`````````````2````8P``````````````$@```.X"
M`````````````"$```">`@`````````````2````I```````````````$@``
M`#H!`````````````!(````L```````````````@````[P(`````````````
M$0```-D!`````````````!(````0`@`````````````2````S@$`````````
M````$@```.$!`````````````!(```"Z`0`````````````2````L0,``%2@
M`0``````$``7`)T#``",.```<`$``!(`#0#5`P``8"T``&@(```2``T`Z`(`
M`"@5``"P`@``$@`-`&,#``"D(0``!````!(`#0!T`P``0)`!```````0`!<`
M<00``*@A``"4`@``$@`-`*<$``#(-0``Q`(``!(`#0!=!```0)`!```````0
M`!<`O`,``#PD```H````$@`-`.(#``"@1@``&`$``!(`#0#Z`P``D$D```0`
M```1``\`.00``%2@`0``````$``7`#X$``!4H`$``````!``%P!I!```6"``
M`%`````2``T`?@0``/@K``!H`0``$@`-`)`$```D*P``O````!(`#0#M`P``
M`)`!```````0`!8`R0,``&0D```D`0``$@`-`*D#``!`D`$``````!``%@`O
M!```/)`!``0````1`!8`4P,``'!)```$````$@`-`!\$```020``8````!(`
M#0#S`P``V!<````````2``T`G@0``!!&``"0````$@`-`.\#````D`$`````
M`"``%@""`P``X"L``!@````2``T`L`,``%2@`0``````$``7``D$``"H(```
M_````!(`#0!3!```N$<``%@!```2``T`1@0``(@E``"<!0``$@`-``!?251-
M7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R
M96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN
M:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?
M<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?
M=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!097)L7V-R;V%K
M7VUE;6]R>5]W<F%P`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R
M:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R
M=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P
M97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%]?97)R
M;F]?;&]C871I;VX`<F5A9`!O<&5N-C0`;'-E96LV-`!P=&AR96%D7V=E='-P
M96-I9FEC`&-L;W-E`&5X:70`<W1R;F-M<`!C;&]S961I<@!?7W-T86-K7V-H
M:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P
M:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?
M7V9P<FEN=&9?8VAK`&UE;6-P>0!L<W1A=#8T`%]?<W1R;F-P>5]C:&L`;W!E
M;F1I<@!S=&1E<G(`9V5T=6ED`')E861L:6YK`'-T<F-H<@!R96%D9&ER-C0`
M7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S
M=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T97)?
M871F;W)K`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\N-2XS-`!L:6)P
M=&AR96%D+G-O+C``;&EB8RYS;RXV`&QD+6QI;G5X+G-O+C,`7U]L:6)C7V-S
M=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`7U]B<W-?<W1A<G1?7P!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?961A=&$`7U]B<W-?
M96YD7U\`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!S
M:&%?=7!D871E`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R
M<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?96YD
M`%]?96YD7U\`<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X
M<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV
M7V-L96%N`'-H85]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R
M+C0`1TQ)0D-?,BXS,P`````````"``(``@`"``(``0`#``(``@`"``0``@`!
M``4``@`!``$``@`"``(``@`%``(``@`!``$``0`!``(``@`!``,``0`"``,`
M`@`"``$``0`"``(``@`!``(``0`#``(``0`!``(``@`!``$``0`!``(``0`"
M``(``0`"``$``@`"``$``0`!``(``@`"``,``@`#``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!`$4#```0````(````!1I:0T```0`O00````````!``$`*P,``!``
M```@````%&EI#0```P"]!`````````$``@`[`P``$`````````"SD98&```%
M`,<$```0````%&EI#0```@"]!````````'R*`0`7````@(H!`!<```"4C`$`
M%P```+B,`0`7````P(P!`!<````$D`$`%P````R0`0`7````$)`!`!<````8
MD`$`%P```!R0`0`7````()`!`!<````DD`$`%P```"B0`0`7````,)`!`!<`
M```TD`$`%P```#R0`0`7````F(P!`!4%``"<C`$`%0@``*",`0`5#0``I(P!
M`!4/``"HC`$`%1L``*R,`0`5'0``L(P!`!4@``"TC`$`%2D``+R,`0`5-@``
MQ(P!`!5```#(C`$`%44``,R,`0`51@``H(L!`!8#``"DBP$`%@0``*B+`0`6
M!0``K(L!`!8'``"PBP$`%@D``+2+`0`6"@``N(L!`!8+``"\BP$`%@P``,"+
M`0`6#@``Q(L!`!80``#(BP$`%A$``,R+`0`6$@``T(L!`!83``#4BP$`%A0`
M`-B+`0`6%0``W(L!`!86``#@BP$`%A<``.2+`0`6&```Z(L!`!89``#LBP$`
M%AH``/"+`0`6'```](L!`!8>``#XBP$`%A\``/R+`0`6(0```(P!`!8B```$
MC`$`%B,```B,`0`6)```#(P!`!8E```0C`$`%B8``!2,`0`6)P``&(P!`!8H
M```<C`$`%BD``"",`0`6*@``)(P!`!8K```HC`$`%BP``"R,`0`6+0``,(P!
M`!8N```TC`$`%B\``#B,`0`6,```/(P!`!8Q``!`C`$`%C(``$2,`0`6,P``
M2(P!`!8T``!,C`$`%C4``%",`0`6-P``5(P!`!8X``!8C`$`%CD``%R,`0`6
M.@``8(P!`!8[``!DC`$`%CP``&B,`0`6/0``;(P!`!8^``!PC`$`%C\``'2,
M`0`60@``>(P!`!9#``!\C`$`%D0``(",`0`61P``A(P!`!9(``"(C`$`%DD`
M`(R,`0`62@``D(P!`!9+```(0"WI?@$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[E
M3'D!``#&C^(7RHSB3/F\Y0#&C^(7RHSB1/F\Y0#&C^(7RHSB//F\Y0#&C^(7
MRHSB-/F\Y0#&C^(7RHSB+/F\Y0#&C^(7RHSB)/F\Y0#&C^(7RHSB'/F\Y0#&
MC^(7RHSB%/F\Y0#&C^(7RHSB#/F\Y0#&C^(7RHSB!/F\Y0#&C^(7RHSB_/B\
MY0#&C^(7RHSB]/B\Y0#&C^(7RHSB[/B\Y0#&C^(7RHSBY/B\Y0#&C^(7RHSB
MW/B\Y0#&C^(7RHSBU/B\Y0#&C^(7RHSBS/B\Y0#&C^(7RHSBQ/B\Y0#&C^(7
MRHSBO/B\Y0#&C^(7RHSBM/B\Y0#&C^(7RHSBK/B\Y0#&C^(7RHSBI/B\Y0#&
MC^(7RHSBG/B\Y0#&C^(7RHSBE/B\Y0#&C^(7RHSBC/B\Y0#&C^(7RHSBA/B\
MY0#&C^(7RHSB?/B\Y0#&C^(7RHSB=/B\Y0#&C^(7RHSB;/B\Y0#&C^(7RHSB
M9/B\Y0#&C^(7RHSB7/B\Y0#&C^(7RHSB5/B\Y0#&C^(7RHSB3/B\Y0#&C^(7
MRHSB1/B\Y0#&C^(7RHSB//B\Y0#&C^(7RHSB-/B\Y0#&C^(7RHSB+/B\Y0#&
MC^(7RHSB)/B\Y0#&C^(7RHSB'/B\Y0#&C^(7RHSB%/B\Y0#&C^(7RHSB#/B\
MY0#&C^(7RHSB!/B\Y0#&C^(7RHSB_/>\Y0#&C^(7RHSB]/>\Y0#&C^(7RHSB
M[/>\Y0#&C^(7RHSBY/>\Y0#&C^(7RHSBW/>\Y0#&C^(7RHSBU/>\Y0#&C^(7
MRHSBS/>\Y0#&C^(7RHSBQ/>\Y0#&C^(7RHSBO/>\Y0#&C^(7RHSBM/>\Y0#&
MC^(7RHSBK/>\Y0#&C^(7RHSBI/>\Y0#&C^(7RHSBG/>\Y0#&C^(7RHSBE/>\
MY0#&C^(7RHSBC/>\Y0#&C^(7RHSBA/>\Y0#&C^(7RHSB?/>\Y0#&C^(7RHSB
M=/>\Y0#&C^(7RHSB;/>\Y5S"G^5<,I_E<$`MZ0S`C^`@T$WB%`"-Y1`0C>4,
M((WE`S"<YQ0`C>(0$(WB#""-XC1"G^4`,)/E'#"-Y0`PH..@___K)"*?Y01`
MC^`@,I_E`B"4YP,`E.<"$*#A^@P`ZQ`RG^4#,)3G`%#3Y0``5>-7```*`#*?
MY0-`E.<``)3EV___Z\8CT.4`,*#A`B""X\8CP^4``)3EU?__ZQ1`G>4$((3B
M!P%RXP-`A.+&,]#E`3"#X\8SP.5C``"*`@&@X6+__^NT(9_EM,&?Y1`0G>4"
M((_@`""2Y0S`C^`44)WE`0!5XP`PH.$$`(SE``"1Y0@@@^6,(9_E``"#Y0(@
MC^`,((/E@"&?Y0(@C^`$((/E3@``V@0`0>(,P(/B!0&`X`3@L>4$X*SE``!1
MX?O__QH#$(7B``"@XU!1G^4``(WE`0&#YT@1G^4%4(_@!""@X0P`E>4!$(_@
M>___ZP!`4.(H```*+%&?Y1A@C>(%4(_@#`"5Y2;__^L<`9_E!A"@X0``C^"H
M``#K``!0XR$```H(,9_E`S"/X`P`D^4$___K8___Z_@@G^6X,)_E`B"/X`,P
MDN<`()/E'#"=Y0(@,^``,*#C(P``&@0`H.$@T(WB<("]Z!?__^O(()_E`B"/
MX```4.,,`(+E&P``"NW^_^N$,)_E`T"4YP``E.5\___K>U?`Y9S__^H,`)7E
M:?__ZP!`H.'2___J"`"5Y0``4.,!```*3@@`Z]C__^IX`)_E!A"@X0``C^![
M``#K``!0XP@`A>71__\*]?__ZDW__^L$$*#CMO__ZM[^_^L!`*#C$O__ZUAV
M`0`,`0``''8!`"@!```P`0``&`$``!0!```\>@$`/'H!```W``#P-@``S'D!
M`#P)``"H>0$`.#0``(!Y`0"X=`$`.'D!`"`S````L*#C`."@XP00G>0-(*#A
M!"`MY00`+>4HH)_E)#"/X@.@BN`@P)_E#,":YP3`+>48,)_E`S":YQ0`G^4`
M`)KGXO[_ZS7__^MT<P$```$``"0!```L`0``%#"?Y10@G^4#,(_@`B"3YP``
M4N,>_R\!W/[_ZE1S`0`@`0``+`"?Y2PPG^4``(_@`S"/X```4^$@,)_E`S"/
MX![_+P$8()_E`C"3YP``4^,>_R\!$_\OX=QW`0#8=P$`(',!``@!```X`)_E
M.#"?Y0``C^`#,(_@`#!#X*,?H.%#$8'@)#"?Y<$0L.$#,(_@'O\O`1@@G^4"
M,)/G``!3XQ[_+P$3_R_AF'<!`)1W`0#0<@$`-`$``$PPG^5,()_E`S"/X``P
MT^4"((_@``!3XQ[_+Q$X,)_E$$`MZ0,PDN<``%/C`@``"B@PG^4#`)_G3_[_
MZ\K__^L<,)_E`2"@XP,PC^``(,/E$("]Z$AW`0"4<@$`!`$``.!V`0`(=P$`
MT/__ZLPPG^7P1RWI`)!0X@,PC^`K```*O""?Y0(PD^<`@)/E``!8XR@```H`
M4-GE`7"@X0``5>,]`%43`5"@$P!0H`,1```:`$"8Y0``5.,,```*"&"@X00`
MH.$%(*#A"1"@X<S^_^L``%#C`@``&@4PU.<]`%/C"P``"@1`MN4``%3C\___
M&@0`H.'PA[WH"5"@X0$P]>4``%/C/0!3$_O__QH)4$7@YO__Z@A@1N`!4(7B
M1F&@X05`A.`$`*#A`&"'Y?"'O>@)0*#A[?__Z@A`H.'K___J+'(!`#@!``!D
M(9_E9#&?Y0(@C^#P02WI`S"2YWC03>(`4%#B`#"3Y70PC>4`,*#C`@``"@`P
MU>4``%/C"@``&C0AG^4L,9_E`B"/X`,PDN<`()/E=#"=Y0(@,^``,*#C0@``
M&GC0C>+P@;WH.O[_ZP!`4.+Q__\*`'&?Y0=PC^`$`*#AA?[_ZP``4.,I```*
M$S#0Y1-@@.(N`%/C`@``&@$PUN4``%/C]/__"A,PT.4N`%/C)```"@4`H.$^
M_O_K`("@X08`H.$[_O_K``"(X`(`@.(F_O_K!S"@X0`@X.,!$*#C!&"-Y0!0
MC>4`8*#A0/[_ZP@0C>(&`*#A^_W_ZP$`<.,&`*#A`P``"A@PG>4/.@/B`0E3
MXQ(```KV_?_K!@"@X=/]_^L$`*#A6_[_ZP``4./5__\:!`"@X6G^_^L%`*#A
MU/W_Z[S__^H!,-;E+@!3X]?__QH",-;E``!3X\;__PK3___JIO__Z^O__^K8
M_?_K5'$!``P!```<<0$`>"\``)`@G^60,)_E`B"/X!!`+>EPT$WB`S"2YPT0
MH.$`0*#A`#"3Y6PPC>4`,*#CMOW_ZP``4.,``*`3!```&A`PG>4/.@/B"@I3
MXP$)4Q,*```*2""?Y4`PG^4"((_@`S"2YP`@D^5L,)WE`B`SX``PH.,'```:
M<-"-XA"`O>@"$*#C!`"@X1O^_^L0#V_AH`*@X>[__^JN_?_KV&\!``P!``"(
M;P$`\$,MZ0%@H.$,$9_E##&?Y0':3>(,T$WB`1"/X`,PD><`0*#A`0J-X@0`
M@.(`,)/E`#"`Y0`PH./D`)_E!'"-XN`@G^4``(_@!Q"@X:S]_^O4@)_E"("/
MX`#`4.(6``#:"%"-X@&03.()4(7@!#!5Y0``4^,E```:``!9XPX```H)(*#A
M+Q"@XP<`H.'M_?_K``!0XP@```J0,)_E`S"8YP``D^4(_O_K"3"@X0<@H.$$
M$*#A\OW_ZP8``.IL,)_E`S"8YP``D^7__?_K!B"@X000H.&'_?_K5""?Y3PP
MG^4"((_@`1J-X@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@XP0``!H!VHWB#-"-
MXO"#O>@,D*#AV?__ZF3]_^LD;P$`#`$``)`M``#_#P``Z&X!`!0!``!<;@$`
M\$<MZ0`PT>40(I_E/0!3XPPRG^4"((_@`4"@X0,PDN<!0($""-!-X@!0H.$$
M`*#A`#"3Y00PC>4`,*#CAOW_ZPT0H.'<@9_E"("/X`!@H.$%`*#AW/[_ZP"0
M4.)````*??W_ZP``5N$W``":N#&?Y0!PG>4#@)CG!W&@X0`PU>4``%/C/0!3
M$P$PH!,`,*`#!0``"@4PH.$!(//E``!2XST`4A/[__\:!3!#X`(`AN(#`(#@
M`&"8Y57]_^L``%#C!P"&YQ4```H`()CE!0"@X0$PT.0'$)+G``!3XST`4Q,`
M,,'E!@``"@$@@>(!,-#D`A"@X3T`4^,``%,3`3#"Y/G__QH],*#C`2"@X0`P
MP>4!,-3D`3#BY0``4^/[__\:""&?Y?@PG^4"((_@`S"2YP`@D^4$,)WE`B`S
MX``PH.,U```:"-"-XO"'O>@!D$GB`3#4Y`$PZ>4``%/C^___&N[__^K`,)_E
M`X"8YP!PF.4`,)?E``!3XR0```H',*#A!""SY0D0H.$``%+C`9")XOK__QH#
M$('B`1&@X9`PG^4#,(_@`""3Y0``4N,/```:`2"@XP$`H.$`((/E%/W_ZP"@
M4.+5__\*!Q"@X0EQH.$'(*#AS/S_ZP"@B.4`,*#C`)"-Y0&0B>(),8KGHO__
MZ@<`H.'K_/_K``!0XP"@H.$``(CEQ?__"@EQH.'R___J`Y"@X0@0H./?___J
MU?S_Z_!M`0`,`0``O&T!`#@!``#<;`$`%'$!`#!`+>EL0)_E;#"?Y01`C^`#
M4)3G#-!-X@``E>5._?_K``"5Y4S]_^M0()_E4#"?Y5`0G^4"()3G`S"/X`$0
MC^`,_?_K``"5Y4/]_^LX,)_E.""?Y3@0G^4#,(_@`,"@XP(@C^`!$(_@"!"-
MZ!;]_^L,T(WB,("]Z,!K`0`4`0``$`$``+!I```X*@``!"T``*`5```L*@``
M$$`MZ3!`G^4P,)_E!$"/X`,PE.<``)/E*?W_ZR`@G^4@,)_E(!"?Y0(@E.<#
M,(_@$$"]Z`$0C^#H_/_J*&L!`!0!```0`0``)&D``*@I``#<()_E<$`MZ=@P
MG^4"VDWB&-!-X@(@C^`#,)+G`AJ-XA00@>(`,)/E`#"!Y0`PH..[_/_KL!"?
MY;`PG^4,0(WB`1"/X`%JC>*D()_E`S"/X!!@AN(#`(WH`1"@XP0`H.'$_/_K
M!`"@X0$JH.,&$*#AC?S_ZP!`4.(`4*"S"```N@$`A.*:_/_K`%!0X@0```H$
M(*#A!A"@X5G\_^L`,*#C!##%YTP@G^4X,)_E`B"/X`(:C>(#,)+G%!"!X@`@
MD^4`,)'E`B`SX``PH.,#```:!0"@X0+:C>(8T(WB<("]Z%S\_^O0:@$`#`$`
M`(PI``!T*0```1```#AJ`0"____J6"*?Y?!/+>E4,I_E0MU-X@S03>("((_@
M`&"@X40"G^4#,)+G0LV-XAB`C>(!4*#A``"/X`@0H.$$P(SB`#"3Y0`PC.4`
M,*#CU_W_ZR\0H.,`0*#A!@"@X7W\_^L``%#C$@``"@`"G^4&$*#A``"/X-K^
M_^L&`*#A\"&?Y>`QG^4"((_@0AV-X@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@
MXVT``!I"W8WB#-"-XO"/O>@&`*#A8/S_ZP"0H.$%`*#A(?S_ZZ@1G^4!$(_@
MD/S_ZP"P4.+B__\*F#&?Y0MPH.$#,(_@%#"-Y8PQG^6,H9_E`S"/X!`PC>4`
M,-?E"J"/X```4^,T```*``!4XP0```H'$*#A!`"@X>3[_^L``%#C.```"@<`
MH.%#_/_K`3!`X@,@U^<#,(?@+P!2XP4``!H`P*#C`,##Y0$@<^4!`$#B+P!2
MX_K__PH!,(GB`#"#X`$*4^.^__^J%"&?Y810C>("((_@"C"@X0$0H.-$`(WI
M!0"@X0$JH.,`<(WE.?S_ZP@0H.$%`*#A]/O_ZP``4.,#```:*#"=Y0\Z`^("
M"5/C&@``"LP0G^4``*#C`1"/X%/\_^L`<*#A``!7XZ3__PH`,-?E``!3X\K_
M_QH``%3C&@``"@`PU.4N`%/C`@``"A1PG>4!`*#CUO__Z@$PU.4``%/C^?__
M&GP0G^4``*#C`1"/X#[\_^L`<*#AZ?__Z@$0H.,%`*#A,_S_ZP``4./?__\:
M5`"?Y040H.$``(_@9O[_ZP4`H.&_^__KB?__ZA!PG>4!`*#COO__ZKW[_^O0
M:0$`#`$``*0H``!T*```9&D!`"@H``#P)P``X"<``/@G``",)P``-"<``.`F
M``"D)@```##0Y0``4^,>_R\!`2"`XB\`4^,"`*`!`3#2Y```4^/Z__\:'O\O
MX1!`+>D`0%#B+@``"@`PU.4``%/C*P``"MC[_^L!,$#B`S"$X`,`5.$J```J
M`R"@X0(``.H$`%+A`C"@X24```H",*#A`1!2Y"\`4>/X__\*`P!4X1\``"H!
M,$/B`P!4X1X```H`(-/E+P!2X_G__QH!,$/B`P``Z@`0T^4!,$/B+P!1XP(`
M`!H#`%3A`R"@X?C__SH$($+@`C""X@$*4^,5``"*:`"?Y000H.$``(_@`$"@
MX0$ZH.,!((+B</O_ZP0`H.$0@+WH2`"?Y1!`O>@``(_@;?O_Z@,`5.'C__\:
M`##4Y2\`4^,%```**`"?Y1!`O>@``(_@9/O_Z@``H.,0@+WH%`"?Y1!`O>@`
M`(_@7OO_ZCQK`0!$)0``3"4```@E```@)9_E(,6?Y2`UG^4"((_@<$`MZ0,P
MDN<,P(_@,-!-X@S`C.(`,)/E+#"-Y0`PH.,/`+SH"."-X@\`KN@/`+SH[&2?
MY>Q4G^4/`*[H!F"/X``PG.4$0(WB!5"/X+`PSN$$$*#A!@"@X=?\_^L``%#C
M#@``"L`TG^4$`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($
M()/E!""#Y```4N/[__\:Z___ZHADG^4&8(_@!!"@X08`H.'!_/_K``!0XPX`
M``IH-)_E!`"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3
MY00@@^0``%+C^___&NO__^HT9)_E!F"/X`00H.$&`*#AJ_S_ZP``4.,.```*
M$#2?Y00`G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$
M((/D``!2X_O__QKK___JX&.?Y09@C^`$$*#A!@"@X97\_^L``%#C#@``"K@S
MG^4$`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#
MY```4N/[__\:Z___ZHQCG^4&8(_@!!"@X08`H.%__/_K``!0XPX```I@,Y_E
M!`"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0`
M`%+C^___&NO__^HX8Y_E!F"/X`00H.$&`*#A:?S_ZP``4.,.```*"#.?Y00`
MG>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D``!2
MX_O__QKK___JY&*?Y09@C^`$$*#A!@"@X5/\_^L``%#C#@``"K`RG^4$`)WE
M`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[
M__\:Z___ZI!BG^4&8(_@!!"@X08`H.$]_/_K``!0XPX```I8,I_E!`"=Y0,P
ME><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___
M&NO__^H\8I_E!F"/X`00H.$&`*#A)_S_ZP``4.,.```*`#*?Y00`G>4#,)7G
M`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O__QKK
M___JZ&&?Y09@C^`$$*#A!@"@X1'\_^L``%#C#@``"J@QG^4$`)WE`S"5YP`0
MD^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[__\:Z___
MZI1AG^4&8(_@!!"@X08`H.'[^__K``!0XPX```I0,9_E!`"=Y0,PE><`$)/E
M`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___&NO__^I`
M`9_E!!"@X0``C^#F^__K`!!0X@(```HL`9_E``"/X.[\_^LD`9_E!!"@X0``
MC^#=^__K`!!0X@(```H0`9_E``"/X.7\_^L(`9_E!!"@X0``C^#4^__K`!!0
MXA(```KT`)_E``"/X-S\_^OL$)_E[`"?Y0$0C^```(_@U_S_Z^`@G^6$,)_E
M`B"/X`,PDN<`()/E+#"=Y0(@,^``,*#C%P``&C#0C>)P@+WHN`"?Y000H.$`
M`(_@N_O_ZP`04.(#```*I`"?Y0``C^##_/_KY?__ZI@0G^4*(*#C`1"/X!D`
MC>*6^O_K``!0X][__QJ``)_E(Q"-X@``C^"W_/_KV?__ZA/Z_^OX90$`"&0`
M``P!``#4)```K&4!`#@!``!X)```*"0``-PC``",(P``1",``(@B``"@(@``
M5"(```@B```T(0``8"$``#0A``!0(0``4"$``$PA``!P(```6"$``+`@``!<
M80$`^"```'P@``#D(```3"```)PPG^6<$)_EG""?Y0,PC^`$X"WE`1"/X```
MD^4"()'G#-!-X@$`<.,`()+E!""-Y0`@H.,*```*<""?Y6@PG^4"((_@`S"2
MYP`@D^4$,)WE`B`SX``PH.,0```:#-"-X@3PG>1(`)_E#1"@X0``C^!N^__K
M``!0XP0```H``-#E,`!0XP``4!,!`*`3``"@`R`PG^4#,(_@``"#Y>7__^K-
M^?_KT&0!`%1@`0`,`0``*&`!`%P?``!(9`$`$$`MZ:?Y_^N@^?_K``!0XP``
MD!40@+WH/"&?Y?!`+>DX,9_E.&&?Y0(@C^`<T$WB`S"2YP9@C^``4*#A$!"-
MX@8`H.$`,)/E%#"-Y0`PH.-'^__K`$!0X@(```H`,-3E``!3XPX``!KX()_E
M[#"?Y0(@C^`#,)+G`""3Y10PG>4"(#/@`#"@XS(``!K8`)_E!1"@X0``C^`<
MT(WB\$"]Z$#\_^H%$*#A;_G_ZP``4.,*```*M""?Y:`PG^4"((_@`S"2YP`@
MD^44,)WE`B`SX``PH.,?```:'-"-XO"`O>@%`*#AQOG_ZP!PH.$$`*#AP_G_
MZP``A^`"`(#BKOG_ZVP@G^5L,)_E`B"/X`,PC^`!$*#C"$"-Y00@C>4`4(WE
M`"#@XP!`H.'$^?_K2""?Y2@PG^4"((_@`S"2YP`@D^44,)WE`B`SX``PH.,$
M$*`!!@"@`<___PIP^?_KA%\!``P!``!D'P``/%\!``0?``#P7@$`L!T``+`=
M``!X7@$`S!>?Y?!/+>G()Y_E@=Q-X@303>(!$(_@O#>?Y1P`C>4""8WB`B"1
MYP,PC^``()+E_""`Y0`@H./\`(#B!P"3Z0%\C>)T@$?B$."#XBA0@^('`(CH
M#P"^Z%S`1^(/`*SH`P">Z&A`1^(#`(SH!P"5Z`<`A.AD!Y_EX&!'X@80H.$`
M`(_@VOK_ZU2GG^4*H(_@`$!0X@(```H`,-3E``!3XQX!`!H?^?_K&/G_ZP"`
M4.+U```*`%"8Y0``5>/Q```*!0"@X6[Y_^N``*#A`0"`XEGY_^L`(-7E``!2
MXP"`H.$,```*_+:?Y0A`H.$+L(_@!`"@X0`@C>4+,*#A`"#@XP$0H.-M^?_K
M`2#UY0)`A.(``%+C]?__&LP&G^584$?B``"/X`(``.H$`)7D``!0XPT```H&
M$*#AK?K_ZP!`4.+X__\*`##4Y0``4^/U__\*/?O_ZP``4./R__\*!`"@X0OY
M_^L`4%#B$P``&@"0H.-TL$?B"2&'X'1`$N4``%3C#```"@%0B>(%48O@`"#4
MY0``4N,'```*!`"@X2K[_^L!D(GB``!0XT,``!H$0)7D``!4X_3__QH`4*#C
M!0"@X2_Y_^L`0*#A"`"@X2SY_^L`0(3@`4N$X@1`A.($`*#A%?G_ZP0VG^4`
M(.#C`S"/X`@PC>7X-9_E`1"@XP,PC^`$,(WE[#6?Y0R`C>4#,(_@`%"-Y0"`
MH.$H^?_K!QV@XP@`H.$N^?_K`0!PXP,``!H?^?_K`!"0Y1$`4>.J```:!A"@
MX0@`H.'"^/_K`%!0XAX```J@)9_E'#"=Y0(0FN>8)9_E``"1Y0`PD^4"((_@
M`1"@XP"`C>4H^?_K`*"@XWPEG^5,-9_E`B"/X`(9C>(#,)+G_!"!X@`@D^4`
M,)'E`B`SX``PH.-(`0`:"@"@X8'<C>($T(WB\(^]Z`0`H.&S^/_K`%!0XJG_
M_PJZ___JT#`7Y0\Z`^(!"5/CW/__&LBP%^6/^/_K``!;X=C__QK0,!?E@SN@
MX:,[H.$'#5/CT___&@0`H.'+^/_K!A"@X0"@H.'L!)_E``"/X#3Z_^L`$%#B
ME0``"APPG>4``)/E1/S_ZP"P4.*0```*"P"@X<_X_^L#`%#C`$"@X0P``)JT
M%)_E!`!`X@``B^`!$(_@9/C_ZP``4.,%```:!`!4X^````H$0(O@!3!4Y2\`
M4^/<```*A$2?Y01`C^``,)3E`0!SXWP```H``%/CB0``"FP4G^5L!)_E`1"/
MX```C^`<^__KK/C_ZUPTG^5<E)_E`S"/X`PPC>54-)_E5'2?Y0,PC^`$,(WE
M3#2?Y4QDG^4#,(_@`"#@XP$0H.,`@(WE"9"/X`=PC^`&8(_@"`"-Y0H`H.&M
M^/_K#P``ZJCX_^L`,)#E$0!3XQ$``!J2^/_K`5"%X@DPH.$$(*#A`1"@XQ!P
MC>4,4(WE`("-Y0#`H.%`$(WI"@"@X9SX_^L'':#C"@"@X:+X_^L!`'#C`$"@
MX>G__PH(`*#A-/C_Z\`#G^4*$*#A``"/X.KZ_^L*`*#AA/[_ZWW__^H%@*#A
M:$!'X@@QA^!H`!/E``!0XS````H!L(CB"U&$X`,``.H$`)7D``!0XRH```H!
ML(OB!A"@X<OY_^L+@*#A`#!0XO;__PH`,-/E``!3X_/__PHL^/_K`%!0XO7^
M_QKH___J"".?Y1PPG>4"`)KG.".?Y0`PD^4``)#E`B"/X`00C>4`@(WE`1"@
MXX'X_^L`H*#C5___ZES^_^L0(Y_EJ#*?Y0(@C^`"&8WB`S"2Y_P0@>(`()/E
M`#"1Y0(@,^``,*#CGP``&@0`H.&!W(WB!-"-XO!/O>@+^/_J#0"@XS/X_^O,
M4I_E4R"@XP50C^``@*#AV/[_ZAPPG>4`L)/E:___ZK`"G^4&$*#A``"/X)7Y
M_^L``%#C9```"@`PT.4``%/C,`!3$P$PH!,`,*`#`3"@$P`PA!4`,(0%=?__
M&@L`H.$`$*#C%OC_ZP!`4.)P__\*`E"@XP`PX.,1(.#C!&!'X@!0C>4%^/_K
M!B"@XP80H.$$`*#AQ??_ZP0P5^4``%/C`@``&@,P5^5#`%/C2```"@`PH.,`
M(*#C`#"-Y00`H.$`,*#C]??_ZYT$`.L`4*#A`@``Z@80H.$%`*#AO`0`ZP(I
MH.,&$*#A!`"@X:_W_^L`(%#B]O__R@0`H.%$0$?B3/C_ZP40H.$$`*#A]@0`
MZ\21G^4P8$?B"9"/X`90H.$!$-3D!0"@X0`0C>4),*#A`"#@XP$0H.,%^/_K
M!`!6X0)0A>+U__\:D#&?Y0`@H.,#,(_@!#"-Y0A@C>4`@(WE""!'Y7@AG^5X
M,9_E`B"/X`P@C>4#,(_@`"#@XP$0H.,*`*#A\O?_ZUK__^H<,)WE!$"3Y0``
M5.,>__\*!`"@X=SW_^L#`%#C&O__FC@1G^4$`$#B``"$X`$0C^!R]__K``!0
MXP2PH`$2___J``"$Y:'__^H",%?E00!3X[/__QH!,%?E0P!3X[#__QH`,-?E
M2`!3XZW__QH!,-?E10!3XZK__QH`,.#C.2#@XP0`H.$`4(WEH??_ZP80H.$I
M(*#C!`"@X6'W_^O`,)_EP!"?Y0,PC^`,,(WEN#"?Y0$0C^`$$(WE`S"/X``@
MX.,!$*#C"@"@X0A@C>4`@(WEO/?_ZR3__^IR]__K&%X!``P!``!X8@$`G!P`
M`*!=`0!$'0``N!P``%@<``!(&P``+!P``!P!```<'```I%L!`,0;``"(&P``
M&%\!`&P:``#@&0``_!L``"0;``!T&0``R!L``"0;``!,&0``J!@``$@9````
M60$`M!@``/@7``"L%P``B!8``.08```4&```R!<``"`8``"<%0``1!<``'0"
MG^5T$I_E``"/X/!`+>D!$)#G:#*?Y0S03>)D(I_E`S"/X``0D>4$$(WE`!"@
MXP)`D^<-8*#A``"4Y<3W_^L`4*#A``"4Y<'W_^MH(-7E!A"@X0`PH.$L`I_E
M:2##Y0``C^#(^/_K``!0XP(```H`,-#E,0!3XV,```K/^__K``"4Y;+W_^L`
M$I_E`S"@XP$@H.,!$(_@4_?_ZP!04.(+```*``"4Y:GW_^L0,)7EW"&?Y0`0
MD^4"((_@+_?_ZQ`PE>4`,)/E"#"3Y0$%$^-:```:``"4Y9WW_^NT$9_E`S"@
MXP$@H.,!$(_@/O?_ZP!04.(+```*G`&?Y080H.$``(_@H/C_ZP!P4.(``)3E
M00``"H[W_^L0,)7E!R"@X0`0D^45]__K``"4Y8CW_^L`4*#A``"4Y87W_^M<
M$9_E`2"@XP$0C^`\]__K4"&?Y0(@C^``$*#A!0"@X0?W_^L``)3E>O?_ZP`@
MH.,&$*#A,%&?Y050C^``,*#A*`&?Y6D@P^4``(_@?_C_ZP``4.,`0*#A"`"%
MY1(```H'':#C!`"@X33W_^L!((#B$0!0XP$`4A,`,*#A)P``BNP@G^6X,)_E
M`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C'0``&@S0C>+P@+WH!`"5Y6G]_^L`
M`%#C`$"@X0@`A>7F__\:K`"?Y0``C^`5]__K`3#0Y0``4^.9__\*E___ZDSW
M_^N0,)_E$""5Y0,PC^`$,)/E``"2Y0`0D^42^?_KN?__Z@``E.5"]__K$#"5
MY0`0D^42]__KGO__ZK;V_^M8()_E6`"?Y0(@C^`$()+E``"/X``0DN4$(*#A
M^?;_Z[Q5`0`,`0``I%4!`!0!``"H%```+!8```P6``#D%0``P!,``(P5``"8
M%0```%D!`#`3````5`$`[!0``$Q8`0`06`$`J!0``$PAG^5,,9_E`B"/X/!`
M+>D#,)+G#-!-X@`PD^4$,(WE`#"@XP!PH.'J^O_K`##0Y0!`H.$``%/C!0``
M"@$@@.(O`%/C`D"@`0$PTN0``%/C^O__&@!AG^4`4%?B!F"/X``PEN4!4*`3
M`0!SXR8```H``%/C`%"@`P%0!1(``%7C"@``&M0@G^7(,)_E`B"/X`,PDN<`
M()/E!#"=Y0(@,^``,*#C*0``&@S0C>+P@+WH`##7Y0``4^/Q__\*H!"?Y00@
MH.,!$(_@!`"@X>/V_^L``%#CZO__&H@@G^5T,)_E`B"/X`,PDN<`()/E!#"=
MY0(@,^``,*#C%```&@<`H.$,T(WB\$"]Z"7X_^I8`)_E#1"@X0``C^#J]__K
M``!0XP``A@76__\*`##0Y0``4^,P`%,3`#"@`P$PH!,`,(8%S___"@$PH.,`
M,(;ERO__ZD?V_^OX4@$`#`$``!A7`0!T4@$`5!(``"!2`0!,$0```````.PK
MG^7L.Y_E`B"/X/!/+>FCWTWB`S"2YPW@H.%`P(#B@&"`X@X0H.$`,)/EA#*-
MY0`PH.,`4*#C!$`<Y0AP'.4D-*#A9R@GX/\\`^(D/(/A(B2@X02$H.$$/(/A
M_RS"X_](".((P(SB9R0BX`0P@^$&`%SA)`"!Z`@P@>4,4('E$!"!XNO__QH(
MP$WB?N^.X@`PH.,,0*#A<""<Y4B0G.5T$)3E"&"\Y4R`E.48<)3E'%"4Y0D@
M(N`$0)SE"!`AX`<@(N`&("+@!1`AX`00(>"B3Z#A@4"$X0(@DN`$((+A#@!<
MX?`HS.'I__\:""N?Y0`0G>4`0)#E('"0Y03`D.4"$)'@!Q"1X*1]H.$0X)#E
M&%"0Y8QRA^$(8)#EA'*'X0R0D.4!<)?@!1`NX":!H.$&$`'@!1`AX`F/B.$!
M<)?@!H^(X0@0G>4DD:#A#)^)X0C`+N`"$)'@!,`,X`[`+.`%$)'@!)^)X0P0
MD>`0P)WE":`HX`+`G.`'H`K@"*`JX`[`G.#G'8'@"L"<X.&MC.`8P)WEJ+"=
MY0+`G.`(P)S@9X$IX`&`".`)@"C@"("<X"#`G>5A$:#A`L"<X`G`G.!GD2'@
M"I`)X&>1*>#JC8C@"<"<X.B=C.`HP)WE`L"<X&?!C.!J<2'@"'`'X`%P)^`'
MP)S@,'"=Y6B!H.$"<)?@`1"7X&IQ*.`)<`?@:G$GX.G-C.`'$)'@['V!X#@0
MG>4"$)'@:A&!X&FA*.`,H`K@"*`JX`H0D>!`H)WE;,&@X0*@FN`(@)K@::$L
MX`>@"N!IH2K@YQV!X`J`F.#AK8C@2("=Y0*`F.!I@8C@9Y$LX`&0">`,D"G@
M"8"8X%"0G>5A$:#A`I"9X`S`F>!GD2'@"I`)X&>1*>#JC8C@"<"<X.B=C.!8
MP)WE`L"<X&?!C.!J<2'@"'`'X`%P)^`'P)S@8'"=Y6B!H.$"<)?@`1"7X&IQ
M*.`)<`?@:G$GX.G-C.`'$)'@['V!X&@0G>4"$)'@:A&!X&FA*.`,H`K@"*`J
MX`H0D>!PH)WE;,&@X0*@FN`(@)K@::$LX`>@"N!IH2K@YQV!X`J`F.#AK8C@
M>("=Y0*`F.!I@8C@9Y$LX`&0">`,D"G@"9"8X("`G>5A$:#A`H"8X`S`F.!G
M@2'@"H`(X&>!*.#JG8G@","<X.F-C."(P)WE`L"<X&?!C.!J<2'@"7`'X`%P
M)^`'P)S@D'"=Y6F1H.$"<)?@`1"7X&IQ*>`(<`?@:G$GX.C-C.`'$)'@['V!
MX)@0G>4"()'@:!$IX`P0`>`)$"'@:B&"X`$@DN#G'8+@H*"=Y2`HG^5LP:#A
M`J":X`F@FN!HD2S@!Y`IX`F0FN`"H)O@:*&*X+"PG>5G@2S@`8`HX.&=B>`(
M@)K@81&@X0*@F^`,H)K@N+"=Y6?!(>`)P"S@Z8V(X`S`FN`"L)O@Z*V,X&=Q
MB^!IP2'@P+"=Y0C`+.`,P)?@:(&@X0)PF^`!<)?@R+"=Y6D1*.`*$"'@ZLV,
MX`$0E^`"<)O@:7&'X-"PG>7LG8'@:A$HX`P0(>`!$)?@;,&@X0*PF^`(@)O@
M:G$LX-BPG>4)<"?@Z1V!X`=PF.`"@)O@:H&(X."PG>7AK8?@:7$LX`%P)^`'
M<)C@81&@X0*`F^`,@)C@Z+"=Y6G!(>`*P"S@ZGV'X`S`F.`"@)O@:8&(X/"P
MG>7GG8S@:L$AX`?`+.`,P)C@9W&@X0*`F^`!@)C@^+"=Y6H1)^`)$"'@Z<V,
MX`$0F.`"@)O@:H&(X.RM@>!I$2?@#!`AX`$0F.``@9WE;,&@X0*`F.`(L9WE
M!X"8X&EQ+.`*<"?@ZAV!X`=PF.`"@)O@:8&(X!"QG>7AG8?@:G$LX`%P)^`'
M<)C@81&@X0*PF^`,P)O@:H$AX!BQG>4)@"C@"("<X`+`F^#I?8?@:L&,X&FA
M(>`'H"K@"J"<X"#!G>5GL:#A`L"<X.>-B.`!P)S@:1$KX`@0(>`!$)S@*,&=
MY>BMBN`"P)S@ZGV!X&G!C.!H$2O@,)&=Y0H0(>`!P)S@:A&@X0*0F>`+D)G@
M:*$AX#BQG>4'H"K@Y\V,X`J@F>`"D)O@9[$AX.0EG^7LK8K@:)&)X`RP*^!L
M@:#A0,&=Y0NPF>!GD8CA`L"<X`'`G.`*D`G@ZAV+X&>Q".`+D(GA"9"<X$C!
MG>5JL0C@`L"<X&=QC.!JP8CA`<`,X`O`C.$'P)S@4'&=Y>&=B>`"<)?@81&@
MX0APE^!J@8'A:K$!X`F`".`+@(CA!X"8X%AQG>7IS8S@`G"7X&JAA^!I<8'A
M:;$!X`QP!^`+<(?A"J"7X&!QG>7LC8C@`G"7X&S!H.$!<)?@Z!V*X&FAC.%I
ML0S@"*`*X`N@BN$'<)K@:*&=Y6BQ#.`"H)K@::&*X&B1C.$!D`G@"Y")X0J@
MF>!PD9WEX7V'X`*0F>!A$:#A#)"9X.?-BN!HH8'A:+$!X`>@"N`+H(KA"9":
MX'BAG>5GL0'@`J":X&BABN#LC8G@9Y&!X0R0">`+D(GA"J"9X("1G>5LP:#A
M`I"9X`&0F>#H'8K@9Z&,X6>Q#.`(H`K@"Z"*X0F0FN"(H9WE:+$,X`*@FN!G
MH8K@X7V)X&B1C.$!D`G@"Y")X0J@F>"0D9WE81&@X0*0F>`,D)G@Y\V*X&BA
M@>%HL0'@!Z`*X`N@BN$)D)K@F*&=Y6>Q`>`"H)K@:*&*X.R-B>!GD8'A#)`)
MX`N0B>$*H)G@H)&=Y6S!H.$"D)G@`9"9X.@=BN!GH8SA9[$,X`B@"N`+H(KA
M"9":X*BAG>5HL0S@`J":X&>ABN#A?8G@:)&,X0&0">`+D(GA"J"9X+"1G>5A
M$:#A`I"9X`R0F>#GS8K@:*&!X6BQ`>`'H`K@"Z"*X0F0FN"XH9WE9[$!X`*@
MFN!HH8K@[(V)X&>1@>$,D`G@"Y")X0J@F>#`D9WE;,&@X0*0F>`!D)G@Z!V*
MX&>AC.%GL0S@"*`*X`N@BN$$,(#E"9":X,BAG>5HL0S@`J":X&>ABN!H<8SA
M`7`'X`MPA^$*<)?@T*&=Y>&=B>`"H)K@81&@X0S`FN!HH8'A:+$!X`F@"N`+
MH(KA#,":X-BAG>7I?8?@`J":X&BABN#GC8S@:<&!X6FQ`>`'P`S@"\",X=PB
MG^4*P)S@X*&=Y6=QH.$"H)K@`:":X.BQG>5I$2?@"!`AX.C-C.`!$)K@`K";
MX.RM@>!ID8O@:!$GX/"QG>4,$"'@`1"9X&S!H.$"D)O@!Y"9X/BQG>5H<2S@
M"G`GX.H=@>`'<)G@`K";X.&=A^!H@8O@:G$LX`"RG>4!<"?@!W"8X&$1H.$"
M@)O@#("8X`BRG>5JP2'@"<`LX.E]A^`,P)C@`H";X&J!B.`0LIWEYZV,X&G!
M(>`'P"S@#,"8X&=QH.$"@)O@`8"8X!BRG>5I$2?@"A`AX.K-C.`!$)C@`H";
MX&F!B.`@LIWE[)V!X&H1)^`,$"'@`1"8X&S!H.$"@)O@!X"8X"BRG>5J<2S@
M"7`GX.D=@>`'<)C@`H";X&J!B.`PLIWEX:V'X&EQ+.`!<"?@!W"8X&$1H.$"
M@)O@#("8X#BRG>5IP2'@"L`LX.I]A^`,P)C@`H";X&F!B.!`LIWEYYV,X&K!
M(>`'P"S@#,"8X&=QH.$"@)O@`8"8X$BRG>5J$2?@"1`AX.G-C.`!$)C@`H";
MX&J!B.!0LIWE[*V!X&D1)^`,$"'@`1"8X&S!H.$"@)O@!X"8X%BRG>5I<2S@
M"G`GX.H=@>`'<)C@`H";X&F!B.!@LIWEX9V'X&IQ+.`!<"?@!W"8X&$1H.$"
M@)O@#("8X&K!(>`)P"S@Z7V'X`S`F.#GS8S@:+*=Y6Q1A>`"@)O@&%"`Y6E1
M(>!J@8C@!U`EX`50F.#L787@<**=Y6=QH.%EX8[@`J":X&F!)^`0X(#E>.*=
MY0R`*.`!$)K@"!"1X`(@GN`$()+@;,$GX`7`+.!I(8+@#""2X.4=@>`@P)#E
MX2V"X``@@.4&$)'@7""?Y0QPE^`,,(#E%#"`Y1PP@.4($(#E('"`Y20P@.4H
M,)_E`B"/X`,PDN<`()/EA#*=Y0(@,^``,*#C`0``&J/?C>+PC[WH0O/_ZX11
M`0`,`0``F7F"6J'KV6[<O!N/UL%BRL!%`0!P0"WI@`"@XU_S_^M44(_BT$#%
MX0`@H./P0,#A3%"/XM!`Q>%X((#E^$#`X410C^+00,7A\$'`X4!0C^+00,7A
M^$'`X3Q0C^+00,7A\$+`X0!`H.,`4*#C^$+`X?!#P.%P@+WH``"@X0$C16<`
M````B:O-[P````#^W+J8`````'94,A``````\.'2PP````#P1RWI*#"0Y0)@
MH.&&P8/@+""0Y0,`7.$`,*#C`B#3X`!0H.$P()#E`4"@X300D.7&#Z#A`0``
M*@$@DN(`$*'B+#"%Y:8^H.&`,8/A`C"3X*`>H>!X`)7E.("%X@``4.,HP(7E
M,#"%Y300A>46```:/P!6XR4``-I`8$;B)I.@X0%PB>('<X3@!!"@X4`@H.,(
M`*#AW/+_ZT!`A.(%`*#AKOS_ZP<`5.'V__\:"9UIX`ECAN`&(*#A!Q"@X0@`
MH.'1\O_K>&"%Y?"'O>A`<&#B!@!7X09PH*$``(C@!R"@X000H.'(\O_K>#"5
MY0,PA^!``%/C>#"%Y?"'O1@%`*#A!V!&X`=`A."4_/_KU___Z@1PH.'F___J
M\$$MZ2@PD>4!0*#A8R@CX#`0D>4B)*#A_RS"XV-T(N!A*"'@HS&@X2(DH.$_
M,`/B_RS"XV%D(N`!((/B.("$XG\0X.,X`%+C`%"@X0,0R.<"`(C@.P``VD`@
M8N(`$*#C#//_ZP0`H.%V_/_K"`"@X3@@H.,`$*#C!O/_ZP0`H.'P9\3A;_S_
MZP,PU.4`,,7ELC#4X0$PQ>4`,)3E!`"@X2,TH.$",,7E`#"4Y0,PQ>4+,-3E
M!##%Y;HPU.$%,,7E"#"4Y2,TH.$&,,7E"#"4Y0<PQ>43,-3E"##%Y;(QU.$)
M,,7E$#"4Y2,TH.$*,,7E$#"4Y0LPQ>4;,-3E###%Y;HQU.$-,,7E&#"4Y2,T
MH.$.,,7E&#"4Y0\PQ>4C,-3E$##%Y;(RU.$1,,7E(#"4Y2,TH.$2,,7E(#"4
MY1,PQ>7P0;WH9_+_ZC@@8N(`$*#CT/+_Z\C__^KP1RWI3&"?Y4Q0G^4&8(_@
M!5"/X`5@1N``<*#A`8"@X0*0H.$\\O_K1F&PX?"'O0@`0*#C!#"5Y`D@H.$(
M$*#A!P"@X0%`A.(S_R_A!`!6X??__QKPA[WH7$$!`%1!`0`>_R_A"#"?Y0,P
MC^``,)/E8?+_ZH1&`0`(0"WI"("]Z`$``@`[````/@````L````^````$```
M`#X````E````/@```#,````^`````P```#X````&````/@```!0````^````
M#@```#X````-````/@```"0````^````$@```#X````G````/@````(````^
M````&````#X````)````/@````H````^```````````````E<R\E<P```"]P
M<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT
M97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO)7,`97AE`"X```!005)?
M5$5-4`````!005)?4%)/1TY!344`````.@```"5S)7,E<P``+P```%!%4DPU
M3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!
M3$E:140`4$%27U-005=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%2
M7T-!0TA%````4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)
M4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`````%!!4E]#3$5!3CT``#$```!,1%],24)205)97U!!5$@`4UE35$5-
M```E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E
M(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%42```
M``!P87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U
M)7,````E<R5S=&5M<"TE=2TE=25S`````!@```!P97)L`````#````!005(Z
M.E!A8VME<CHZ5D524TE/3@`````Q+C`U-````%5N86)L92!T;R!C<F5A=&4@
M8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A
M8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````+64`
M`"TM``!54T52`````%5315).04U%`````%1%35!$25(`5$U0`"]T;7``````
M979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF
M(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?
M<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)'!A<E]T96UP+"`D<')O9VYA;64L
M($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?
M0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO
M=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD
M9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T
M96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>
M3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I4
M14U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]
M/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@
M)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR
M;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T
M:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M
M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL
M96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F
M(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P
M<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]
M"D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@
M/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D
M96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O
M)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@
M(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P
M;W,L("1D871A7W!O<RD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]]
M(#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA
M;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE
M(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N
M;RYP;0IL87-T($U!1TE#.PI]"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T
M.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US(%]&2#L*;7D@)&UA9VEC7W!O<R`]
M("1S:7IE("T@)'-I>F4@)2`D8VAU;FM?<VEZ93L@(R!.3U1%.B`D;6%G:6-?
M<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1M86=I
M8U]P;W,@/CT@,"D@>PIS965K(%]&2"P@)&UA9VEC7W!O<RP@,#L*<F5A9"!?
M1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII
M9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2![
M"B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D8VAU
M;FM?<VEZ93L*?0II9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG
M="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R
M;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@-"P@,#L*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`D;6%G:6-?
M<&]S("T@-"`M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T85]P;W,@/2!T
M96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B
M1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F
M+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F
M=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL
M;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF
M7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X
M="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI
M>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT
M(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN
M86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL
M96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\
M7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@
M)&9I;&5N86UE(#T@7W-A=F5?87,H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P
M-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1-
M;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^
M("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F
M=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#
M(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF
M(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#
M86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R
M97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E
M<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F
M:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B
M.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD
M9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE
M;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U
M9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@
M)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL
M96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG
M(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#
M*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U
M:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE
M.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L
M:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA
M;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I
M*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@
M=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]
M"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*=6YL97-S("@D
M8G5F(&5Q(")02UPP,#-<,#`T(BD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A
M9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T
M($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@
M("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H
M)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D
M14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@
M82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!
M4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*
M<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL
M7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6
M(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%
M3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`
M05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI
M+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE
M;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@
M)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@
M>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I
M970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^
M/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A
M73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD[
M"FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\
M.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P
M87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;
M17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5E;G8@
M/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S
M*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T
M82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD
M+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\
M.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P
M87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;
M(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`B4$M<
M,#`S7#`P-"(["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H
M*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H
M*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B
M.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO
M861E<CL*:68@*&1E9FEN960@)&1A=&%?<&]S*2!["G)E860@7T9(+"`D;&]A
M9&5R+"`D9&%T85]P;W,["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L
M;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH
M7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E
M96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E
M=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%
M3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@
M+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI
M?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T
M:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PII9B`H)&)U
M;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D[
M"FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE
M(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB
M97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*
M?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I
M;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?
M;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ
M0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE
M>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D
M9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D
M:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K
M97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@
M/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L
M("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA
M;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL
M97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL[
M"FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN
M72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C
M;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[
M8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D9F@L
M("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z
M("0A73L*)&-O;G1E;G0@/2`\)&9H/CL*8VQO<V4@)&9H.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA
M;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH
M/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I
M;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I
M;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O
M;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*
M)&-O;G1E;G0I.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*
M)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?
M;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE
M7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1O=70["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4@)&9H.PHD8V%C
M:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD
M9F@M/G!R:6YT*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U
M+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?
M<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@
M;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H
M7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R
M(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S
M:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T
M:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S
M("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R
M7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E
M<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E
M<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>
M+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA
M;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT
M<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M
M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B
M)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E
M<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M
M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(ETI.PHD;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA
M;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,
M:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;
M+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@
M>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H
M.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[
M(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E
M(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR
M97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I
M<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U
M:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5
M;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE
M9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E
M<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@
M7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$[
M"G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@
M<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W
M*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64[
M"FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@
M9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I
M("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H
M9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@
M>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\
M("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D
M:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S
M97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?
M0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@
M>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["G-E96L@)&9H+"`M,3@L(#([
M"FUY("1B=68["G)E860@)&9H+"`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#
M04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<F5A9"`D9F@L("1B=68L(#0Q
M.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D<WES>U]D96QI;7UC
M86-H92TD8G5F(CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U
M:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q
M*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64[
M"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7UC86-H92TD9&EG97-T(CL*?0IC
M;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M
M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-
M4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*
M)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L
M("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R
M7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M
M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^.G)A=R<L
M("1T96UP;F%M92!O<B!D:64@<7%;0V%N)W0@=W)I=&4@(B1T96UP;F%M92(Z
M("0A73L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D
M;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M
M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T
M=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I
M;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345]
M(#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]
M("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P
M<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I
M.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M
M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG
M+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P
M<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5]
M.PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[
M<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%
M3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER
M(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I
M<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D
M<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T
M*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@
M7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]0
M4D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*
M?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E
M=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\[
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I
M;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I
M('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R
M.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!0
M4D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H
M<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N
M)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]
M*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@
M)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H
M)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#
M3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]
M"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2![
M"G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*
M?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L
M(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA
M<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV
M96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*
M<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI0
M05(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O
M<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@
M9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`[
M"GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ
M.PI?7T5.1%]?"@```'!E<FQX<VDN8P```%]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@`````#L````^````"P```#X````0````/@```"4````^
M````,P```#X````#````/@````8````^````%````#X````.````/@````T`
M```^````)````#X````2````/@```"<````^`````@```#X````8````/@``
M``D````^````"@```#X``````````````&B-_W\!`````````%`9``#H&```
M`0```!L#```!````*P,```$````[`P```0```$4#```,````+!(```T```"(
M20``&0```'R*`0`;````!````!H```"`B@$`'`````0```#U_O]OK`$```4`
M``!,"0``!@```)P"```*````T@0```L````0````%0`````````#````E(L!
M``(```#H`0``%````!$````7````1!```!$```!D#P``$@```.`````3````
M"````!X````(````^___;P$```C^__]O]`X``/___V\#````\/__;QX.``#Z
M__]O$```````````````````````````````````````````````````````
M``"$B@$````````````X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(`
M`#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``
M.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X
M$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2
M```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(`
M`#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``<$D`````````````
M````````````````````````````````$$D````````H%0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````20`0#_____4$T``(!*````````0$L``$1+``!$30``
MB$H``$Q-````````,$T``#A-````````6$T``$=#0SH@*$1E8FEA;B`Q,2XR
M+C`M,38I(#$Q+C(N,`!!*@```&%E86)I``$@````!35410`&!`@!"0$2!!,!
M%`$5`1<#&`$9`1H"`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL
M9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`
M+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT
M`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%232YE>&ED>``N96A?9G)A
M;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T
M80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````````````
M``````````````````````````````````````L````!`````@```%0!``!4
M`0``$P```````````````0`````````3````!P````(```!H`0``:`$``"0`
M``````````````0`````````)@````<````"````C`$``(P!```@````````
M```````$`````````#0```#V__]O`@```*P!``"L`0``\`````4`````````
M!`````0````^````"P````(```"<`@``G`(``+`&```&`````P````0````0
M````1@````,````"````3`D``$P)``#2!``````````````!`````````$X`
M``#___]O`@```!X.```>#@``U@````4``````````@````(```!;````_O__
M;P(```#T#@``]`X``'`````&`````P````0`````````:@````D````"````
M9`\``&0/``#@````!0`````````$````"````',````)````0@```$00``!$
M$```Z`$```4````5````!`````@```!\`````0````8````L$@``+!(```P`
M``````````````0`````````=P````$````&````.!(``#@2``#P`@``````
M```````$````!````((````!````!@```"@5```H%0``8#0`````````````
M"`````````"(`````0````8```"(20``B$D```@```````````````0`````
M````C@````$````"````D$D``)!)``#@0``````````````$`````````)8`
M```!``!P@@```'"*``!PB@``"`````T`````````!`````````"A`````0``
M``(```!XB@``>(H```0```````````````0`````````JP````X````#````
M?(H!`'R*```$```````````````$````!````+<````/`````P```("*`0"`
MB@``!```````````````!`````0```##````!@````,```"$B@$`A(H``!`!
M```&``````````0````(````S`````$````#````E(L!`)2+```\`0``````
M```````$````!````-$````!`````P````"0`0``D```0```````````````
M!`````````#7````"`````,```!`D`$`0)```!00``````````````0`````
M````W`````$````P`````````$"0```?```````````````!`````0```.4`
M```#``!P``````````!?D```*P```````````````0`````````!`````P``
A````````````BI```/4```````````````$`````````
